#ifndef EFL_CANVAS_GESTURE_IMPL_HH
#define EFL_CANVAS_GESTURE_IMPL_HH

#include "efl_canvas_gesture.eo.hh"

namespace efl { namespace canvas { 
inline ::efl::eolian::return_traits<Efl_Event_Description const&>::type Gesture::type_get() const
{
   const Efl_Event_Description * __return_value =  ::efl_gesture_type_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Event_Description const&>::type>(__return_value);
}
inline ::efl::eolian::return_traits<Efl_Canvas_Gesture_State>::type Gesture::state_get() const
{
   Efl_Canvas_Gesture_State __return_value =  ::efl_gesture_state_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Canvas_Gesture_State>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Gesture::state_set( ::efl::eolian::in_traits<Efl_Canvas_Gesture_State>::type state) const
{
    ::efl_gesture_state_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Canvas_Gesture_State,  ::efl::eolian::in_traits<Efl_Canvas_Gesture_State>::type>(state));
}
inline ::efl::eolian::return_traits<Eina_Vector2>::type Gesture::hotspot_get() const
{
   Eina_Vector2 __return_value =  ::efl_gesture_hotspot_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Vector2>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Gesture::hotspot_set( ::efl::eolian::in_traits<Eina_Vector2>::type hotspot) const
{
    ::efl_gesture_hotspot_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Vector2,  ::efl::eolian::in_traits<Eina_Vector2>::type>(hotspot));
}
} } 
namespace eo_cxx {
namespace efl { namespace canvas { 
inline ::efl::eolian::return_traits<Efl_Event_Description const&>::type Gesture::type_get() const
{
   const Efl_Event_Description * __return_value =  ::efl_gesture_type_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Event_Description const&>::type>(__return_value);
}
inline ::efl::eolian::return_traits<Efl_Canvas_Gesture_State>::type Gesture::state_get() const
{
   Efl_Canvas_Gesture_State __return_value =  ::efl_gesture_state_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Canvas_Gesture_State>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Gesture::state_set( ::efl::eolian::in_traits<Efl_Canvas_Gesture_State>::type state) const
{
    ::efl_gesture_state_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Canvas_Gesture_State,  ::efl::eolian::in_traits<Efl_Canvas_Gesture_State>::type>(state));
}
inline ::efl::eolian::return_traits<Eina_Vector2>::type Gesture::hotspot_get() const
{
   Eina_Vector2 __return_value =  ::efl_gesture_hotspot_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Vector2>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Gesture::hotspot_set( ::efl::eolian::in_traits<Eina_Vector2>::type hotspot) const
{
    ::efl_gesture_hotspot_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Vector2,  ::efl::eolian::in_traits<Eina_Vector2>::type>(hotspot));
}
inline efl::canvas::Gesture::operator ::efl::canvas::Gesture() const { return *static_cast< ::efl::canvas::Gesture const*>(static_cast<void const*>(this)); }
inline efl::canvas::Gesture::operator ::efl::canvas::Gesture&() { return *static_cast< ::efl::canvas::Gesture*>(static_cast<void*>(this)); }
inline efl::canvas::Gesture::operator ::efl::canvas::Gesture const&() const { return *static_cast< ::efl::canvas::Gesture const*>(static_cast<void const*>(this)); }
} } }
#endif
